@@ -1,5 +1,4 @@
 # SNMP::Info::CiscoPortSecurity
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,6 +30,7 @@
 package SNMP::Info::CiscoPortSecurity;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
@@ -39,7 +39,7 @@ use SNMP::Info;
 
 our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE, %PAECAPABILITIES);
 
-$VERSION = '3.68';
+$VERSION = '3.70';
 
 %MIBS = (
     'CISCO-PORT-SECURITY-MIB' => 'ciscoPortSecurityMIB',
@@ -110,7 +110,7 @@ $VERSION = '3.68';
 
 %PAECAPABILITIES = (
     0 => 'dot1xPaePortAuthCapable',
-    1 => 'dot1xPaePortSuppCapable'
+    1 => 'dot1xPaePortSuppCapable',
 );
 
 sub munge_pae_capabilities {
