@@ -1,5 +1,4 @@
 # SNMP::Info::CiscoPower
-# $Id$
 #
 # Copyright (c) 2008 Bill Fenner
 # All rights reserved.
@@ -31,6 +30,7 @@
 package SNMP::Info::CiscoPower;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
@@ -39,10 +39,11 @@ use SNMP::Info;
 
 our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.68';
+$VERSION = '3.70';
 
 %MIBS = ( 'CISCO-POWER-ETHERNET-EXT-MIB' => 'cpeExtPsePortEntPhyIndex',
-          'CISCO-CDP-MIB' => 'cdpCachePowerConsumption' );
+          'CISCO-CDP-MIB' => 'cdpCachePowerConsumption',
+);
 
 %GLOBALS = ();
 
@@ -153,6 +154,8 @@ Note that it requires that the device inherits from Info::Entity.
 
 =item F<CISCO-POWER-ETHERNET-EXT-MIB>
 
+=item F<CISCO-CDP-MIB>
+
 =back
 
 =head1 GLOBALS
