@@ -1,5 +1,4 @@
 # SNMP::Info::FDP
-# $Id$
 #
 # Copyright (c) 2008 Bruce Rodger, Max Baker
 # All rights reserved.
@@ -34,15 +33,16 @@
 package SNMP::Info::FDP;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::FDP::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::FDP::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.34';
+$VERSION = '3.70';
 
 %MIBS = ( 'FOUNDRY-SN-SWITCH-GROUP-MIB' => 'snFdpGlobalRun' );
 
@@ -50,11 +50,9 @@ $VERSION = '3.34';
     'fdp_run'      => 'snFdpGlobalRun',
     'fdp_interval' => 'snFdpGlobalMessageInterval',
     'fdp_holdtime' => 'snFdpGlobalHoldTime',
-    'fdp_id'       => 'snFdpGlobalDeviceId',
 );
 
 %FUNCS = (
-    'fdp_index'        => 'snFdpCacheIfIndex',
     'fdp_proto'        => 'snFdpCacheAddressType',
     'fdp_ip'           => 'snFdpCacheAddress',
     'fdp_ver'          => 'snFdpCacheVersion',
@@ -62,14 +60,12 @@ $VERSION = '3.34';
     'fdp_port'         => 'snFdpCacheDevicePort',
     'fdp_platform'     => 'snFdpCachePlatform',
     'fdp_capabilities' => 'snFdpCacheCapabilities',
-    'fdp_domain'       => 'snFdpCacheVTPMgmtDomain',
-    'fdp_vlan'         => 'snFdpCacheNativeVLAN',
-    'fdp_duplex'       => 'snFdpCacheDuplex',
+    'fdp_cache_type'   => 'snFdpCacheVendorId',
 );
 
 %MUNGE = (
     'fdp_capabilities' => \&SNMP::Info::munge_bits,
-    'fdp_ip'           => \&SNMP::Info::munge_ip
+    'fdp_ip'           => \&SNMP::Info::munge_ip,
 );
 
 sub fdp_run {
@@ -84,9 +80,7 @@ sub fdp_run {
 sub hasFDP {
     my $fdp = shift;
 
-    my $ver = $fdp->{_version};
-
-    #my $ver = $fdp->fdp_ver;
+    my $ver = $fdp->snmp_ver();
 
     # SNMP v1 clients dont have the globals
     if ( defined $ver and $ver == 1 ) {
@@ -103,11 +97,6 @@ sub hasFDP {
 sub fdp_if {
     my $fdp = shift;
 
-    # See if by some miracle Cisco implemented the fdpCacheIfIndex entry
-    my $fdp_index = $fdp->fdp_index();
-    return $fdp_index if defined $fdp_index;
-
-    # Nope, didn't think so. Now we fake it.
     my $fdp_ip = $fdp->fdp_ip();
     unless ( defined $fdp_ip ) {
         $fdp->error_throw(
@@ -143,10 +132,10 @@ Bruce Rodger, Max Baker
 
 =head1 SYNOPSIS
 
- my $fdp = new SNMP::Info ( 
+ my $fdp = new SNMP::Info (
                              AutoSpecify => 1,
                              Debug       => 1,
-                             DestHost    => 'router', 
+                             DestHost    => 'router',
                              Community   => 'public',
                              Version     => 2
                            );
@@ -157,7 +146,7 @@ Bruce Rodger, Max Baker
  $hasfdp   = $fdp->hasFDP() ? 'yes' : 'no';
 
  # Print out a map of device ports with FDP neighbors:
- my $interfaces = $fdp->interfaces();
+ my $interfaces   = $fdp->interfaces();
  my $fdp_if       = $fdp->fdp_if();
  my $fdp_ip       = $fdp->fdp_ip();
  my $fdp_port     = $fdp->fdp_port();
@@ -172,7 +161,7 @@ Bruce Rodger, Max Baker
 
 =head1 DESCRIPTION
 
-SNMP::Info::FDP is a subclass of SNMP::Info that provides an object oriented 
+SNMP::Info::FDP is a subclass of SNMP::Info that provides an object oriented
 interface to FDP information through SNMP.
 
 FDP is a Layer 2 protocol that supplies topology information of
@@ -183,7 +172,7 @@ virtually identical.  FDP is implemented in Brocade (Foundry) devices.
 Create or use a device subclass that inherits this class.  Do not use
 directly.
 
-Each device implements a subset of the global and cache entries. 
+Each device implements a subset of the global and cache entries.
 Check the return value to see if that data is held by the device.
 
 =head2 Inherited Classes
@@ -197,11 +186,11 @@ None.
 =item F<FOUNDRY-SN-SWITCH-GROUP-MIB>
 
 Needs a reasonably recent MIB. Works OK with B2R07604A.mib, but doesn't
-work with B2R07600C. 
+work with B2R07600C.
 
 =back
 
-=head1 GLOBAL METHODS
+=head1 GLOBALS
 
 These are methods that return scalar values from SNMP
 
@@ -209,13 +198,13 @@ These are methods that return scalar values from SNMP
 
 =item  $fdp->hasFDP()
 
-Is FDP is active in this device?  
+Is FDP is active in this device?
 
 Accounts for SNMP version 1 devices which may have FDP but not fdp_run()
 
 =item $fdp->fdp_run()
 
-Is FDP enabled on this device?  
+Is FDP enabled on this device?
 
 (C<fdpGlobalRun>)
 
@@ -227,19 +216,10 @@ Interval in seconds at which FDP messages are generated.
 
 =item $fdp->fdp_holdtime()
 
-Time in seconds that FDP messages are kept. 
+Time in seconds that FDP messages are kept.
 
 (C<fdpGlobalHoldTime>)
 
-=item  $fdp->fdp_id() 
-
-Returns FDP device ID.  
-
-This is the device id broadcast via FDP to other devices, and is what is
-retrieved from remote devices with $fdp->id().
-
-(C<fdpGlobalDeviceId>)
-
 =back
 
 =head2 Overrides
@@ -256,13 +236,13 @@ Interval in seconds at which FDP messages are generated.
 
 =item $fdp->fdp_holdtime()
 
-Time in seconds that FDP messages are kept. 
+Time in seconds that FDP messages are kept.
 
 (C<fdpGlobalHoldTime>)
 
-=item  $fdp->fdp_id() 
+=item  $fdp->fdp_id()
 
-Returns FDP device ID.  
+Returns FDP device ID.
 
 This is the device id broadcast via FDP to other devices, and is what is
 retrieved from remote devices with $fdp->id().
@@ -323,19 +303,6 @@ Thanks to Martin Lorensen for a pointer to this information.
 
 (C<fdpCacheCapabilities>)
 
-=item $fdp->fdp_domain()
-
-The CDP version of this returns remote VTP Management Domain as defined
-in C<CISCO-VTP-MIB::managementDomainName>
-
-(C<fdpCacheVTPMgmtDomain>)
-
-=item $fdp->fdp_duplex() 
-
-Returns the port duplex status from remote devices.
-
-(C<fdpCacheDuplex>)
-
 =item $fdp->fdp_id()
 
 Returns remote device id string
@@ -346,19 +313,11 @@ Returns remote device id string
 
 Returns the mapping to the SNMP Interface Table.
 
-Note that a lot devices don't implement $fdp->fdp_index(),  So if it isn't
-around, we fake it. 
-
 In order to map the fdp table entry back to the interfaces() entry, we
 truncate the last number off of it :
 
-  # it exists, yay.
-  my $fdp_index     = $device->fdp_index();
-  return $fdp_index if defined $fdp_index;
-
-  # if not, let's fake it
   my $fdp_ip       = $device->fdp_ip();
-    
+
   my %fdp_if
   foreach my $key (keys %$fdp_ip){
       $iid = $key;
@@ -366,30 +325,18 @@ truncate the last number off of it :
       $iid =~ s/\.\d+$//;
       $fdp_if{$key} = $iid;
   }
- 
+
   return \%fdp_if;
 
-
-=item $fdp->fdp_index()
-
-Returns the mapping to the SNMP2 Interface table for FDP Cache Entries. 
-
-Most devices don't implement this, so you probably want to use $fdp->fdp_if()
-instead.
-
-See fdp_if() entry.
-
-(C<fdpCacheIfIndex>)
-
 =item  $fdp->fdp_ip()
 
 Returns remote IP address
 
 (C<fdpCacheAddress>)
 
-=item $fdp->fdp_platform() 
+=item $fdp->fdp_platform()
 
-Returns remote platform id 
+Returns remote platform id
 
 (C<fdpCachePlatform>)
 
@@ -405,17 +352,17 @@ Returns remote address type received.  Usually IP.
 
 (C<fdpCacheAddressType>)
 
-=item $fdp->fdp_ver() 
+=item $fdp->fdp_ver()
 
 Returns remote hardware version
 
 (C<fdpCacheVersion>)
 
-=item $fdp->fdp_vlan()
+=item $fdp->fdp_cache_type()
 
-Returns the remote interface native VLAN.
+Returns type of entry received, either FDP or CDP.
 
-(C<fdpCacheNativeVLAN>)
+(C<snFdpCacheVendorId>)
 
 =back
 
