@@ -29,8 +29,8 @@
 package SNMP::Info::Layer2::Airespace;
 
 use strict;
+use warnings;
 use Exporter;
-use SNMP::Info::Bridge;
 use SNMP::Info::CDP;
 use SNMP::Info::Airespace;
 
@@ -40,7 +40,7 @@ use SNMP::Info::Airespace;
 
 our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.68';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::MIBS,      %SNMP::Info::Bridge::MIBS,
@@ -272,11 +272,6 @@ Eric Miller
 Provides abstraction to the configuration information obtainable from
 Cisco (Airespace) Wireless Controllers through SNMP.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
-my $airespace = new SNMP::Info::Layer2::Airespace(...);
-
 =head2 Inherited Classes
 
 =over
