@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3 - SNMP Interface to Layer3 devices
-# $Id$
 #
 # Copyright (c) 2008 Max Baker -- All changes from Version 0.7 on
 #
@@ -33,6 +32,7 @@
 package SNMP::Info::Layer3;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 use SNMP::Info::Bridge;
@@ -41,28 +41,34 @@ use SNMP::Info::Entity;
 use SNMP::Info::PowerEthernet;
 use SNMP::Info::IPv6;
 use SNMP::Info::AdslLine;
+use SNMP::Info::LLDP;
+use SNMP::Info::DocsisHE;
 
 @SNMP::Info::Layer3::ISA = qw/
     SNMP::Info::PowerEthernet SNMP::Info::IPv6
     SNMP::Info::Entity SNMP::Info::EtherLike
     SNMP::Info::Bridge SNMP::Info::AdslLine
+    SNMP::Info::LLDP SNMP::Info::DocsisHE
     SNMP::Info Exporter/;
 @SNMP::Info::Layer3::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '2.06';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::MIBS,
     %SNMP::Info::AdslLine::MIBS,
     %SNMP::Info::Bridge::MIBS,
+    %SNMP::Info::DocsisHE::MIBS,
     %SNMP::Info::EtherLike::MIBS,
     %SNMP::Info::Entity::MIBS,
     %SNMP::Info::PowerEthernet::MIBS,
     %SNMP::Info::IPv6::MIBS,
+    %SNMP::Info::LLDP::MIBS,
     'IP-MIB'   => 'ipNetToMediaIfIndex',
     'OSPF-MIB' => 'ospfRouterId',
+    'ISIS-MIB' => 'isisSysID',
     'BGP4-MIB' => 'bgpIdentifier',
 );
 
@@ -72,10 +78,12 @@ $VERSION = '2.06';
     %SNMP::Info::GLOBALS,
     %SNMP::Info::AdslLine::GLOBALS,
     %SNMP::Info::Bridge::GLOBALS,
+    %SNMP::Info::DocsisHE::GLOBALS,
     %SNMP::Info::EtherLike::GLOBALS,
     %SNMP::Info::Entity::GLOBALS,
     %SNMP::Info::PowerEthernet::GLOBALS,
     %SNMP::Info::IPv6::GLOBALS,
+    %SNMP::Info::LLDP::GLOBALS,
     'mac' => 'ifPhysAddress.1',
     'serial1' =>
         '.1.3.6.1.4.1.9.3.6.3.0',    # OLD-CISCO-CHASSIS-MIB::chassisId.0
@@ -88,10 +96,12 @@ $VERSION = '2.06';
     %SNMP::Info::FUNCS,
     %SNMP::Info::AdslLine::FUNCS,
     %SNMP::Info::Bridge::FUNCS,
+    %SNMP::Info::DocsisHE::FUNCS,
     %SNMP::Info::EtherLike::FUNCS,
     %SNMP::Info::Entity::FUNCS,
     %SNMP::Info::PowerEthernet::FUNCS,
     %SNMP::Info::IPv6::FUNCS,
+    %SNMP::Info::LLDP::FUNCS,
 
     # Obsolete Address Translation Table (ARP Cache)
     'old_at_index'   => 'atIfIndex',
@@ -118,6 +128,20 @@ $VERSION = '2.06';
     'ospf_peer_id'    => 'ospfNbrRtrId',
     'ospf_peer_state' => 'ospfNbrState',
 
+    # ISIS-MIB::isisCircTable
+    'isis_circ_if_idx'      => 'isisCircIfIndex' ,
+    'isis_circ_admin'       => 'isisCircAdminState',
+    'isis_circ_type'        => 'isisCircType',
+    'isis_circ_level_type'  => 'isisCircLevelType',
+
+    # ISIS-MIB::isisISAdjTable
+    'isis_adj_state'   => 'isisISAdjState',
+    'isis_adj_type'    => 'isisISAdjNeighSysType',
+    'isis_adj_usage'   => 'isisISAdjUsage',
+    'isis_adj_id'      => 'isisISAdjNeighSysID',
+    'isis_adj_ip_type' => 'isisISAdjIPAddrType',
+    'isis_adj'         => 'isisISAdjIPAddrAddress',
+
     # BGP4-MIB::bgpPeerTable
     'bgp_peers'               => 'bgpPeerLocalAddr',
     'bgp_peer_id'             => 'bgpPeerIdentifier',
@@ -132,11 +156,11 @@ $VERSION = '2.06';
     'bgp_peer_out_upd'        => 'bgpPeerOutUpdates',
 
     # IP-MIB Net to Physical Table (ARP Cache)
-    'n2p_paddr' => 'ipNetToPhysicalPhysAddress',
+    'n2p_paddr'      => 'ipNetToPhysicalPhysAddress',
     'n2p_lastupdate' => 'ipNetToPhysicalLastUpdated',
-    'n2p_ptype' => 'ipNetToPhysicalType',
-    'n2p_pstate' => 'ipNetToPhysicalState',
-    'n2p_pstatus' => 'ipNetToPhysicalRowStatus',
+    'n2p_ptype'      => 'ipNetToPhysicalType',
+    'n2p_pstate'     => 'ipNetToPhysicalState',
+    'n2p_pstatus'    => 'ipNetToPhysicalRowStatus',
 
 );
 
@@ -147,14 +171,42 @@ $VERSION = '2.06';
     %SNMP::Info::AdslLine::MUNGE,
     %SNMP::Info::Bridge::MUNGE,
     %SNMP::Info::EtherLike::MUNGE,
+    %SNMP::Info::DocsisHE::MUNGE,
     %SNMP::Info::Entity::MUNGE,
     %SNMP::Info::PowerEthernet::MUNGE,
     %SNMP::Info::IPv6::MUNGE,
+    %SNMP::Info::LLDP::MUNGE,
     'old_at_paddr' => \&SNMP::Info::munge_mac,
     'at_paddr'     => \&SNMP::Info::munge_mac,
-    'n2p_paddr' => \&SNMP::Info::munge_mac,
+    'n2p_paddr'    => \&SNMP::Info::munge_mac,
 );
 
+sub isis_peers {
+    my $l3 = shift;
+
+    my $isis_peers = {};
+
+    # Returns hexstrings. Need to convert to IPv4 dotted or IPv6 hex notation
+    my $adjacencies = $l3->isis_adj();
+    foreach my $key (keys %$adjacencies) {
+        my $hexstr = $adjacencies->{$key};
+        my $l = length $hexstr;
+        my $ip;
+        # 4 bytes = IPv4
+        if ($l == 4) {
+            $ip = join(".", unpack("C*", $hexstr));
+            $isis_peers->{$key} = $ip;
+        }
+        # 16 bytes = IPv6
+        elsif ($l == 16) {
+            $ip = unpack("H*", $hexstr);
+            $ip =~ s/....(?=.)\K/:/sg ;
+            $isis_peers->{$key} = $ip;
+        }
+    }
+    return $isis_peers;
+}
+
 # Method OverRides
 
 sub root_ip {
@@ -163,6 +215,14 @@ sub root_ip {
     my $router_ip = $l3->router_ip();
     my $ospf_ip   = $l3->ospf_ip();
 
+   # if the router ip exists and is a route advertised by the device we prefer
+   # it over the others
+    return $router_ip
+        if (( defined $router_ip )
+        and ( $router_ip ne '0.0.0.0' )
+        and ( grep { $ospf_ip->{$_} eq $router_ip } ( keys %$ospf_ip ) )
+        and ( $l3->snmp_connect_ip($router_ip) ) );
+
     # return the first one found here (should be only one)
     if ( defined $ospf_ip and scalar( keys %$ospf_ip ) ) {
         foreach my $key ( keys %$ospf_ip ) {
@@ -174,48 +234,24 @@ sub root_ip {
         }
     }
 
-    return $router_ip
-        if (( defined $router_ip )
-        and ( $router_ip ne '0.0.0.0' )
-        and ( $l3->snmp_connect_ip($router_ip) ) );
     return;
 }
 
-sub i_ignore {
-    my $l3      = shift;
-    my $partial = shift;
-
-    my $interfaces = $l3->interfaces($partial) || {};
-
-    my %i_ignore;
-    foreach my $if ( keys %$interfaces ) {
-
-        # lo -> cisco aironet 350 loopback
-        if ( $interfaces->{$if} =~ /(tunnel|loopback|\blo\b|null)/i ) {
-            $i_ignore{$if}++;
-        }
-    }
-    return \%i_ignore;
-}
-
 sub serial {
     my $l3 = shift;
 
-    my $serial1  = $l3->serial1();
-    my $e_descr  = $l3->e_descr() || {};
-    my $e_serial = $l3->e_serial() || {};
+    my $entity_serial = $l3->entity_derived_serial();
+    if ( defined $entity_serial and $entity_serial !~ /^\s*$/ ){
+        return $entity_serial;
+    }
 
-    my $serial2 = $e_serial->{1} || undef;
-    my $chassis = $e_descr->{1}  || undef;
-
-    # precedence
-    #   serial2,chassis parse,serial1
-    return $serial2 if ( defined $serial2 and $serial2 !~ /^\s*$/ );
-    return $1
-        if ( defined $chassis and $chassis =~ /serial#?:\s*([a-z0-9]+)/i );
-    return $serial1 if ( defined $serial1 and $serial1 !~ /^\s*$/ );
+    my $serial1 = $l3->serial1();
+    if ( defined $serial1 and $serial1 !~ /^\s*$/ ) {
+        return $serial1;
+    }
 
     return;
+
 }
 
 # $l3->model() - the sysObjectID returns an IID to an entry in
@@ -289,32 +325,47 @@ sub interfaces {
     my $l3      = shift;
     my $partial = shift;
 
-    my $interfaces   = $l3->i_index($partial);
-    my $descriptions = $l3->i_description($partial);
+    my $interfaces = $l3->i_index($partial);
+    my $i_descr    = $l3->i_description($partial);
 
-    my %interfaces = ();
-    foreach my $iid ( keys %$interfaces ) {
-        my $desc = $descriptions->{$iid};
-        next unless defined $desc;
+    # Check for duplicates in ifDescr, if so uniquely identify by adding
+    # ifIndex to repeated values
+    my (%seen, %first_seen_as);
+    foreach my $iid ( sort keys %$i_descr ) {
+        my $port = $i_descr->{$iid};
+        next unless defined $port;
 
-        $interfaces{$iid} = $desc;
+        $port = SNMP::Info::munge_null($port);
+        $port =~ s/^\s+//; $port =~ s/\s+$//;
+        next unless length $port;
+
+        if ( $seen{$port}++ ) {
+            # (#320) also fixup the port this is a duplicate of
+            $interfaces->{ $first_seen_as{$port} }
+              = sprintf( "%s (%d)", $port, $first_seen_as{$port} );
+
+            $interfaces->{$iid} = sprintf( "%s (%d)", $port, $iid );
+        }
+        else {
+            $interfaces->{$iid} = $port;
+            $first_seen_as{$port} = $iid;
+        }
     }
-
-    return \%interfaces;
+    return $interfaces;
 }
 
 sub vendor {
     my $l3 = shift;
 
     my $descr = $l3->description();
-    my $id = $l3->id();
+    my $id    = $l3->id();
 
     # .1.3.6.1.4.1.9.1 is the CISCO-PRODUCTS-MIB
     # .1.3.6.1.4.1.9.9.368.4 is an old tree that Cisco CSSs were numbered from
-    return 'cisco'   if $id =~ /^\Q.1.3.6.1.4.1.9.1.\E\d+$/;
-    return 'cisco'   if $id =~ /^\Q.1.3.6.1.4.1.9.9.368.4.\E\d+/;
+    return 'cisco' if $id =~ /^\Q.1.3.6.1.4.1.9.1.\E\d+$/;
+    return 'cisco' if $id =~ /^\Q.1.3.6.1.4.1.9.9.368.4.\E\d+/;
     return 'cisco'   if ( $descr =~ /(cisco|\bios\b)/i );
-    return 'foundry' if ( $descr =~ /foundry/i );
+    return 'brocade' if ( $descr =~ /foundry/i );
 
     return 'unknown';
 
@@ -356,14 +407,14 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $l3 = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $l3->class();
@@ -386,11 +437,11 @@ This class is usually used as a superclass for more specific device classes
 listed under SNMP::Info::Layer3::*   Please read all docs under SNMP::Info
 first.
 
-Provides generic methods for accessing SNMP data for Layer 3 network devices. 
-Includes support for Layer2+3 devices. 
+Provides generic methods for accessing SNMP data for Layer 3 network devices.
+Includes support for Layer2+3 devices.
 
 For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
+after determining a more specific class using the method above.
 
  my $l3 = new SNMP::Info::Layer3(...);
 
@@ -410,6 +461,12 @@ after determining a more specific class using the method above.
 
 =item SNMP::Info::IPv6
 
+=item SNMP::Info::LLDP
+
+=item SNMP::Info::DocsisHE
+
+=item SNMP::Info::AdslLine
+
 =back
 
 =head2 Required MIBs
@@ -418,6 +475,8 @@ after determining a more specific class using the method above.
 
 =item F<IP-MIB>
 
+=item F<ISIS-MIB>
+
 =item F<OSPF-MIB>
 
 =item F<BGP4-MIB>
@@ -426,7 +485,7 @@ after determining a more specific class using the method above.
 
 =head2 Inherited MIBs
 
-See L<SNMP::Info/"Required MIBs"> for its MIB requirements.
+See L<SNMP::Info/"REQUIREMENTS"> for its MIB requirements.
 
 See L<SNMP::Info::Bridge/"Required MIBs"> for its MIB requirements.
 
@@ -438,6 +497,12 @@ See L<SNMP::Info::PowerEthernet/"Required MIBs"> for its MIB requirements.
 
 See L<SNMP::Info::IPv6/"Required MIBs"> for its MIB requirements.
 
+See L<SNMP::Info::LLDP/"Required MIBs"> for its MIB requirements.
+
+See L<SNMP::Info::DocsisHE/"Required MIBs"> for its MIB requirements.
+
+See L<SNMP::Info::AdslLine/"Required MIBs"> for its MIB requirements.
+
 =head1 GLOBALS
 
 These are methods that return scalar value from SNMP
@@ -462,7 +527,7 @@ Returns the BGP identifier of the local system
 
 =item $l3->bgp_local_as()
 
-Returns the local autonomous system number 
+Returns the local autonomous system number
 
 (C<bgpLocalAs.0>)
 
@@ -480,8 +545,7 @@ Removes 'cisco'  from cisco devices for readability.
 
 =item $l3->serial()
 
-Tries to cull a serial number from F<ENTITY-MIB>, description, and
-F<OLD-CISCO->... MIB.
+Returns a serial number if found from F<ENTITY-MIB> and F<OLD-CISCO->... MIB.
 
 =item $l3->vendor()
 
@@ -497,7 +561,7 @@ found:  OSPF Router ID (C<ospfRouterId>) or any OSPF Host IP Address
 
 =head2 Globals imported from SNMP::Info
 
-See L<SNMP::Info/"GLOBALS"> for details.
+See L<SNMP::Info/"USAGE"> for details.
 
 =head2 Global Methods imported from SNMP::Info::Bridge
 
@@ -511,6 +575,26 @@ See L<SNMP::Info::EtherLike/"GLOBALS"> for details.
 
 See L<SNMP::Info::Entity/"GLOBALS"> for details.
 
+=head2 Global Methods imported from SNMP::Info:PowerEthernet
+
+See L<SNMP::Info::PowerEthernet/"GLOBALS"> for details.
+
+=head2 Global Methods imported from SNMP::Info::IPv6
+
+See L<SNMP::Info::IPv6/"GLOBALS"> for details.
+
+=head2 Global Methods imported from SNMP::Info::LLDP
+
+See L<SNMP::Info::LLDP/"GLOBALS"> for details.
+
+=head2 Global Methods imported from SNMP::Info::DocsisHE
+
+See L<SNMP::Info::DocsisHE/"GLOBALS"> for details.
+
+=head2 Global Methods imported from SNMP::Info::AdslLine
+
+See L<SNMP::Info::AdslLine/"GLOBALS"> for details.
+
 =head1 TABLE METHODS
 
 These are methods that return tables of information in the form of a reference
@@ -523,19 +607,13 @@ to a hash.
 =item $l3->interfaces()
 
 Returns the map between SNMP Interface Identifier (iid) and physical port
-name. 
+name.
 
 Only returns those iids that have a description listed in $l3->i_description()
 
-=item $l3->i_ignore()
-
-Returns reference to hash.  Creates a key for each IID that should be ignored.
-
-Currently looks for tunnel,loopback,lo,null from $l3->interfaces()
-
 =item $l3->i_name()
 
-Returns reference to hash of iid to human set name. 
+Returns reference to hash of iid to human set name.
 
 Defaults to C<ifName>, but checks for an C<ifAlias>
 
@@ -543,10 +621,10 @@ Defaults to C<ifName>, but checks for an C<ifAlias>
 
 Returns reference to hash of iid to current link duplex setting.
 
-Maps $l3->el_index() to $l3->el_duplex, then culls out 
-full,half, or auto and sets the map to that value. 
+Maps $l3->el_index() to $l3->el_duplex, then culls out
+full,half, or auto and sets the map to that value.
 
-See L<SNMP::Info::Etherlike> for the el_index() and el_duplex() methods.
+See L<SNMP::Info::EtherLike> for the el_index() and el_duplex() methods.
 
 =back
 
@@ -556,7 +634,7 @@ See L<SNMP::Info::Etherlike> for the el_index() and el_duplex() methods.
 
 =item $l3->at_index()
 
-Returns reference to hash.  Maps ARP table entries to Interface IIDs 
+Returns reference to hash.  Maps ARP table entries to Interface IIDs
 
 (C<ipNetToMediaIfIndex>)
 
@@ -565,7 +643,7 @@ the deprecated C<atIfIndex>.
 
 =item $l3->at_paddr()
 
-Returns reference to hash.  Maps ARP table entries to MAC addresses. 
+Returns reference to hash.  Maps ARP table entries to MAC addresses.
 
 (C<ipNetToMediaPhysAddress>)
 
@@ -574,7 +652,7 @@ the deprecated C<atPhysAddress>.
 
 =item $l3->at_netaddr()
 
-Returns reference to hash.  Maps ARP table entries to IP addresses. 
+Returns reference to hash.  Maps ARP table entries to IP addresses.
 
 (C<ipNetToMediaNetAddress>)
 
@@ -762,9 +840,85 @@ routers
 
 =back
 
+=head2 IS-IS Circuit Table
+
+=over
+
+=item $l3->isis_circ_if_idx()
+
+Returns reference to hash of the interface index associated with the IS-IS
+circuit
+(C<isisCircIfIndex>)
+
+=item $l3->isis_circ_admin()
+
+Returns reference to hash of the IS-IS circuit's admin status
+
+(C<isisCircAdminState>)
+
+=item $l3->isis_circ_type()
+
+Returns reference to hash of the IS-IS circuit's type
+
+(C<isisCircType>)
+
+=item $l3->isis_circ_level_type()
+
+Returns reference to hash of the IS-IS circuit's level
+
+(C<isisCircLevelType>)
+
+=back
+
+=head2 IS-IS Adjacency Table
+
+=over
+
+=item $l3->isis_adj_id()
+
+Returns reference to hash of the peer id of adjacencies.
+
+(C<isisISAdjNeighSysID>)
+
+=item $l3->isis_adj_type()
+
+Returns reference to hash of the type of adjacencies (Level 1
+Intermediate System, Level 2 Intermediate System, Level 1+2
+Intermediate System, unknown)
+
+(C<isisISAdjNeighSysType>)
+
+=item $l3->isis_adj_usage()
+
+Returns reference to hash of the type of adjacencies in use
+(undefined, Level 1, Level 2, Level1+2)
+
+(C<isisISAdjNeighUsage>)
+
+=item $l3->isis_adj_ip_type()
+
+Returns reference to hash of type of address (IPv4, IPv6, etc) on adjacencies.
+
+(C<isisISAdjIPAddrType>)
+
+=item $l3->isis_adj()
+
+Returns reference to hash of addresses (IPv4, IPv6, etc) on adjacencies.
+Note this returns hash-strings, for IPs, use $l3->isis_peers()
+
+(C<isisISAdjIPAddrAddress>)
+
+=item $l3->isis_peers()
+
+Returns reference to hash of addresses (IPv4, IPv6) on adjacencies.
+Convert hash strings from isis_adj to proper
+IP (v4 and v6) formatting.
+
+=back
+
 =head2 Table Methods imported from SNMP::Info
 
-See L<SNMP::Info/"TABLE METHODS"> for details.
+See L<SNMP::Info/"USAGE"> for details.
 
 =head2 Table Methods imported from SNMP::Info::Bridge
 
@@ -786,4 +940,16 @@ See L<SNMP::Info::PowerEthernet/"TABLE METHODS"> for details.
 
 See L<SNMP::Info::IPv6/"TABLE METHODS"> for details.
 
+=head2 Table Methods imported from SNMP::Info::LLDP
+
+See L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
+
+=head2 Table Methods imported from SNMP::Info::DocsisHE
+
+See L<SNMP::Info::DocsisHE/"TABLE METHODS"> for details.
+
+=head2 Table Methods imported from SNMP::Info::AdslLine
+
+See L<SNMP::Info::AdslLine/"TABLE METHODS"> for details.
+
 =cut
