@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::AlcatelLucent
-# $Id$
 #
 # Copyright (c) 2008 Bill Fenner
 #
@@ -30,6 +29,7 @@
 package SNMP::Info::Layer3::AlcatelLucent;
 
 use strict;
+use warnings;
 
 use Exporter;
 use SNMP::Info::Layer3;
@@ -47,9 +47,9 @@ use SNMP::Info::LLDP;
     SNMP::Info::MAU SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::AlcatelLucent::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.34';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -112,15 +112,15 @@ sub vendor {
 }
 
 sub os_ver {
-    my $alu = shift;
+   my $alu = shift;
 
-    my $descr = $alu->description();
-    if ( $descr =~ m/^(\S+)/ ) {
-        return $1;
-    }
+   my $descr = $alu->description();
+   if (defined ($descr)) {
+     return $1 if $descr =~ m/\b(\d[\.\d]+R\d+) (?:GA|Service Release), /;
+   }
 
-    # No clue what this will try but hey
-    return $alu->SUPER::os_ver();
+   # No clue what this will try but hey
+   return $alu->SUPER::os_ver();
 }
 
 # ps1_type, ps1_status, ps2_type, ps2_status:
@@ -308,7 +308,7 @@ Bill Fenner
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $alu = new SNMP::Info(
                         AutoSpecify => 1,
                         Debug       => 1,
@@ -316,7 +316,7 @@ Bill Fenner
                         DestHost    => 'myswitch',
                         Community   => 'public',
                         Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $alu->class();
@@ -372,7 +372,7 @@ These are methods that return scalar value from SNMP
 
 =item $alu->vendor()
 
-    Returns 'alcatel-lucent'
+Returns 'alcatel-lucent'
 
 =item $alu->model()
 
