@@ -30,6 +30,7 @@
 package SNMP::Info::Layer3::F5;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 
@@ -38,7 +39,7 @@ use SNMP::Info::Layer3;
 
 our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.68';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -321,11 +322,6 @@ Eric Miller
 
 Abstraction subclass for F5 network devices.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $f5 = new SNMP::Info::Layer3::F5(...);
-
 =head2 Inherited Classes
 
 =over
