@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::Pf
-# $Id$
 #
 # Copyright (c) 2010 Max Baker
 # All rights reserved.
@@ -31,21 +30,19 @@
 package SNMP::Info::Layer3::Pf;
 
 use strict;
+use warnings;
 use Exporter;
-
 use SNMP::Info::Layer3;
-use SNMP::Info::LLDP;
 
-@SNMP::Info::Layer3::Pf::ISA = qw/SNMP::Info::LLDP SNMP::Info::Layer3 Exporter/;
+@SNMP::Info::Layer3::Pf::ISA = qw/SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::Pf::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '2.06';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     # Enterprise container where BEGEMOT-* lives
     'FOKUS-MIB' => 'fokus',
     # MIBs used included in Layer3 and above:
@@ -72,21 +69,18 @@ $VERSION = '2.06';
 
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
 );
 
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
 );
 
 %MUNGE = (
     %SNMP::Info::Layer3::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
 );
 
 sub vendor {
-    return 'FreeBSD';
+    return 'freebsd';
 }
 
 sub model {
@@ -118,42 +112,6 @@ sub os_ver {
     return $os_ver;
 }
 
-# Use LLDP
-sub hasCDP {
-    my $pf = shift;
-    return $pf->hasLLDP();
-}
-
-sub c_ip {
-    my $pf  = shift;
-    my $partial = shift;
-    return $pf->lldp_ip($partial);
-}
-
-sub c_if {
-    my $pf  = shift;
-    my $partial = shift;
-    return $pf->lldp_if($partial);
-}
-
-sub c_port {
-    my $pf  = shift;
-    my $partial = shift;
-    return $pf->lldp_port($partial);
-}
-
-sub c_id {
-    my $pf  = shift;
-    my $partial = shift;
-    return $pf->lldp_id($partial);
-}
-
-sub c_platform {
-    my $pf  = shift;
-    my $partial = shift;
-    return $pf->lldp_rem_sysdesc($partial);
-}
-
 1;
 __END__
 
@@ -168,7 +126,7 @@ Max Baker
 =head1 SYNOPSIS
 
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $pf = new SNMP::Info(
                         AutoSpecify => 1,
                         Debug       => 1,
@@ -176,7 +134,7 @@ Max Baker
                         DestHost    => 'myswitch',
                         Community   => 'public',
                         Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $pf->class();
@@ -184,7 +142,7 @@ Max Baker
 
 =head1 DESCRIPTION
 
-Subclass for Free-BSD PF-Based devices
+Subclass for FreeBSD PF-Based devices
 
 =head1 LLDP Support
 
@@ -193,7 +151,7 @@ that the available CDP/LLDP modules for net-snmp don't work on FreeBSD (on
 which pfSense is based) as they assume certain Linux specific Ethernet
 structures.  This problem is apparently solved on PF based firewall appliances
 by using the ladvd package, for which a port may be found here:
-L<http://www.freshports.org/net/ladvd/>.  I'm not sure if this module ties into 
+L<http://www.freshports.org/net/ladvd/>.  I'm not sure if this module ties into
 Net-SNMP or not.
 
 =head2 Inherited Classes
@@ -202,8 +160,6 @@ Net-SNMP or not.
 
 =item SNMP::Info::Layer3
 
-=item SNMP::Info::LLDP
-
 =back
 
 =head2 Required MIBs
@@ -216,8 +172,6 @@ Net-SNMP or not.
 
 See L<SNMP::Info::Layer3/"Required MIBs"> for its own MIB requirements.
 
-See L<SNMP::Info::LLDP/"Required MIBs"> for its own MIB requirements.
-
 =back
 
 =head1 GLOBALS
@@ -228,11 +182,7 @@ These are methods that return scalar values from SNMP
 
 =item $pf->vendor()
 
-    Returns 'FreeBSD'
-
-=item $pf->hasCDP()
-
-    Returns whether LLDP is enabled.
+Returns 'freebsd'
 
 =item $pf->model()
 
@@ -245,7 +195,7 @@ Returns 'Pf'
 =item $pf->os_ver()
 
 Tries to reference $pf->id() to one of the product MIBs listed above.
-Will probably return a truncation of the default OID for pf-based systems 
+Will probably return a truncation of the default OID for pf-based systems
 C<enterprises.12325.1.1.2.1.1>.
 
 =back
@@ -259,36 +209,8 @@ See documentation in L<SNMP::Info::Layer3/"GLOBALS"> for details.
 These are methods that return tables of information in the form of a reference
 to a hash.
 
-=over
-
-=item $pf->c_id()
-
-Returns LLDP information.
-
-=item $pf->c_if()
-
-Returns LLDP information.
-
-=item $pf->c_ip()
-
-Returns LLDP information.
-
-=item $pf->c_platform()
-
-Returns LLDP information.
-
-=item $pf->c_port()
-
-Returns LLDP information.
-
-=back
-
 =head2 Table Methods imported from SNMP::Info::Layer3
 
 See documentation in L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
-
 =cut
