@@ -1,5 +1,4 @@
-# SNMP::Info::MAU - Media Access Unit - RFC 2668
-# $Id$
+# SNMP::Info::MAU - Medium Attachment Unit - RFC 2668
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 #
@@ -33,15 +32,16 @@
 package SNMP::Info::MAU;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::MAU::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::MAU::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.31';
+$VERSION = '3.70';
 
 %MIBS = ( 'MAU-MIB' => 'mauMod', 'IANA-MAU-MIB' => 'dot3MauType' );
 
@@ -277,7 +277,7 @@ sub mau_set_i_speed_admin {
     my $rv;
 
     $speed = lc($speed);
-    if ( !( $speed =~ /(10|100|1000|auto)/io and $iid =~ /\d+/o ) ) {
+    if ( !( $speed =~ /^(10|100|1000|auto)$/i and $iid =~ /\d+/ ) ) {
         return;
     }
 
@@ -298,7 +298,7 @@ sub mau_set_i_speed_admin {
     my $myduplex;
 
     my $i_mau_def_type
-        = &SNMP::translateObj( $mau->mau_type_admin($iid)->{ $iid . '.1' } );
+        = &SNMP::translateObj( $mau->mau_type_admin($key)->{ $key } );
 
     if ( $i_mau_def_type =~ /^dot3MauType.*Base.*(..)$/
         && ( $1 eq "HD" or $1 eq "FD" ) )
@@ -315,17 +315,17 @@ sub mau_set_i_speed_admin {
         return (1);
     }
     elsif ( $speed eq "auto" ) {
-        $rv = $mau->set_mau_autostat( 'enabled', $iid . '.1' );
+        $rv = $mau->set_mau_autostat( 'enabled', $key );
         return ($rv);
     }
     else {
         if ( $i_autoneg eq "enabled" ) {
-            $mau->set_mau_autostat( 'disabled', $iid . '.1' );
+            $mau->set_mau_autostat( 'disabled', $key );
         }
         $rv
             = $mau->set_mau_type_admin(
             '.1.3.6.1.2.1.26.4.' . $speeds{$myduplex}{$speed},
-            $iid . '.1' );
+            $key );
 
         return ($rv);
     }
@@ -340,7 +340,7 @@ sub mau_set_i_duplex_admin {
 
     $duplex = lc($duplex);
 
-    if ( !( $duplex =~ /(full|half|auto)/i and $iid =~ /\d+/ ) ) {
+    if ( !( $duplex =~ /^(full|half|auto)$/i and $iid =~ /\d+/ ) ) {
         return;
     }
 
@@ -356,7 +356,7 @@ sub mau_set_i_duplex_admin {
     my $i_autoneg = $myhash->{$key};
 
     my $i_speed
-        = &SNMP::translateObj( $mau->mau_type_admin($iid)->{ $iid . '.1' } );
+        = SNMP::translateObj( $mau->mau_type_admin($key)->{ $key } );
 
     if ( $i_speed =~ /^dot3MauType(.*)Base/ && $_mau_i_speed_map{$1} ) {
         $i_speed = $1;
@@ -371,7 +371,7 @@ sub mau_set_i_duplex_admin {
         return (1);
     }
     elsif ( $duplex eq "auto" ) {
-        $rv = $mau->set_mau_autostat( 'enabled', $iid . '.1' );
+        $rv = $mau->set_mau_autostat( 'enabled', $key );
         return ($rv);
     }
     else {
@@ -380,12 +380,12 @@ sub mau_set_i_duplex_admin {
         if ( $i_autoneg eq "enabled"
             && defined( $duplexes{$i_speed}{$duplex} ) )
         {
-            $mau->set_mau_autostat( 'disabled', $iid . '.1' );
+            $mau->set_mau_autostat( 'disabled', $key );
         }
         $rv
             = $mau->set_mau_type_admin(
             '.1.3.6.1.2.1.26.4.' . $duplexes{$i_speed}{$duplex},
-            $iid . '.1' );
+            $key );
         return ($rv);
     }
 }
@@ -420,7 +420,7 @@ sub mau_set_i_speed_duplex_admin {
         return ("bad arguments");
     }
 
-    # map input speed and duplex paramters to 'mau_type_admin' settings
+    # map input speed and duplex parameters to 'mau_type_admin' settings
     # From IANA-MAU-MIB
     # 11 = dot3MauType10BaseTFD, 10 = dot3MauType10BaseTHD,
     # 16 = dot3MauType100BaseTXFD, 15 = dot3MauType100BaseTXHD
@@ -451,7 +451,7 @@ __END__
 
 =head1 NAME
 
-SNMP::Info::MAU - SNMP Interface to Medium Access Unit (MAU) MIB (RFC 2668)
+SNMP::Info::MAU - SNMP Interface to Medium Attachment Unit (MAU) MIB (RFC 2668)
 via SNMP
 
 =head1 AUTHOR
@@ -460,14 +460,14 @@ Max Baker
 
 =head1 SYNOPSIS
 
- my $mau = new SNMP::Info ( 
+ my $mau = new SNMP::Info (
                              AutoSpecify => 1,
                              Debug       => 1,
-                             DestHost    => 'hpswitch', 
+                             DestHost    => 'hpswitch',
                              Community   => 'public',
                              Version     => 2
                            );
- 
+
  my $class = $mau->class();
  print " Using device sub class : $class\n";
 
@@ -475,7 +475,7 @@ Max Baker
 
 SNMP::Info::MAU is a subclass of SNMP::Info that supplies access to the
 F<MAU-MIB> (RFC 2668). This MIB is sometimes implemented on Layer 2 network
-devices like HP Switches.  MAU = Media Access Unit.
+devices.  MAU = Medium Attachment Unit.
 
 The MAU table contains link and duplex info for the port itself and the device
 connected to that port.
@@ -497,6 +497,8 @@ None.
 
 =item F<MAU-MIB>
 
+=item F<IANA-MAU-MIB>
+
 =back
 
 =head1 GLOBALS
@@ -551,14 +553,14 @@ and their index in the MAU IF Table.
 
 (C<ifMauIfIndex>)
 
-=item $mau->mau_link() - Returns the type of Media Access used.  
+=item $mau->mau_link() - Returns the type of Media Access used.
 
-    This is essentially the type of link in use.  
+    This is essentially the type of link in use.
     eg. dot3MauType100BaseTXFD - 100BaseT at Full Duplex
 
 (C<ifMauType>)
 
-=item $mau->mau_status() - Returns the admin link condition as 
+=item $mau->mau_status() - Returns the admin link condition as
 
     1 - other
     2 - unknown
@@ -576,9 +578,9 @@ Use 5 and !5 to see if the link is up or down on the admin side.
  (C<ifMauMediaAvailable>)
 
 =item $mau->mau_type() - Returns a 32bit string reporting the capabilities
-of the port from a MAU POV. 
+of the port from a MAU POV.
 
-  Directly from F<MAU-MIB> : 
+  Directly from F<MAU-MIB> :
           Bit   Capability
             0      other or unknown
             1      AUI
@@ -619,14 +621,14 @@ ports.
 (C<ifMauAutoNegAdminStatus>)
 
 =item $mau->mau_autosent() - Returns a 32 bit bit-string representing the
-capabilities we are broadcasting on that port 
+capabilities we are broadcasting on that port
 
     Uses the same decoder as $mau->mau_type().
 
 (C<ifMauAutoNegCapAdvertised>)
 
-=item $mau->mau_autorec() - Returns a 32 bit bit-string representing the 
-capabilities of the device on the other end. 
+=item $mau->mau_autorec() - Returns a 32 bit bit-string representing the
+capabilities of the device on the other end.
 
     Uses the same decoder as $mau->mau_type().
 
@@ -641,7 +643,7 @@ or provide a simpler interface to complex set operations.  See
 L<SNMP::Info/"SETTING DATA VIA SNMP"> for general information on set
 operations.
 
-=over 
+=over
 
 =item $mau->mau_set_i_speed_admin(speed, ifIndex)
 
@@ -684,7 +686,7 @@ Accepts the following values for speed and duplex:
 
 =head1 Utility Functions
 
-=over 
+=over
 
 =item munge_int2bin() - Unpacks an integer into a 32bit bit string.
 
